@@ -2,16 +2,26 @@
 
 # This will replace the old Google Sheets connector that works with the Bearer API
 import asyncio
+import os
 from contextlib import suppress
-from typing import Any, Dict, Optional
+from pathlib import Path
+from typing import Optional
 
 import pandas as pd
 from aiohttp import ClientSession
 from pydantic import Field, create_model
 
 from toucan_connectors.common import ConnectorStatus, HttpError, fetch, get_loop
-from toucan_connectors.oauth2_connector.oauth2connector import OAuth2Connector
-from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource, strlist_to_enum
+from toucan_connectors.oauth2_connector.oauth2connector import (
+    OAuth2Connector,
+    OAuth2ConnectorConfig,
+)
+from toucan_connectors.toucan_connector import (
+    ConnectorConfigForm,
+    ToucanConnector,
+    ToucanDataSource,
+    strlist_to_enum,
+)
 
 AUTHORIZATION_URL: str = (
     'https://accounts.google.com/o/oauth2/auth?access_type=offline&prompt=consent'
@@ -62,9 +72,6 @@ class GoogleSheets2DataSource(ToucanDataSource):
         return create_model('FormSchema', **constraints, __base__=cls).schema()
 
 
-Secrets = Dict[str, Any]
-
-
 class GoogleSheets2Connector(ToucanConnector):
     """The Google Sheets connector."""
 
@@ -77,6 +84,13 @@ class GoogleSheets2Connector(ToucanConnector):
     # TODO: turn into a class property
     _baseroute = 'https://sheets.googleapis.com/v4/spreadsheets/'
 
+    @staticmethod
+    def get_connector_config_form() -> ConnectorConfigForm:
+        return ConnectorConfigForm(
+            documentation_md=(Path(os.path.dirname(__file__)) / 'doc.md').read_text(),
+            config_schema=OAuth2ConnectorConfig.schema(),
+        )
+
     def __init__(self, **kwargs):
         super().__init__(
             **{k: v for k, v in kwargs.items() if k not in OAuth2Connector.init_params}
@@ -87,7 +101,12 @@ class GoogleSheets2Connector(ToucanConnector):
             authorization_url=AUTHORIZATION_URL,
             scope=SCOPE,
             token_url=TOKEN_URL,
-            **{k: v for k, v in kwargs.items() if k in OAuth2Connector.init_params},
+            config=OAuth2ConnectorConfig(
+                client_id=kwargs['client_id'],
+                client_secret=kwargs['client_secret'],
+                redirect_uri=kwargs['redirect_uri'],
+            ),
+            secrets_keeper=kwargs['secrets_keeper'],
         )
 
     def build_authorization_url(self, **kwargs):
