@@ -6,6 +6,7 @@ from urllib import parse as url_parse
 
 from authlib.common.security import generate_token
 from authlib.integrations.requests_client import OAuth2Session
+from pydantic import BaseModel, SecretStr
 
 
 class SecretsKeeper(ABC):
@@ -22,35 +23,37 @@ class SecretsKeeper(ABC):
         """
 
 
+class OAuth2ConnectorConfig(BaseModel):
+    client_id: str
+    client_secret: SecretStr
+    redirect_uri: str
+
+
 class OAuth2Connector:
-    init_params = ['client_secret', 'client_id', 'redirect_uri', 'secrets_keeper']
+    init_params = ['secrets_keeper'] + list(OAuth2ConnectorConfig.schema()['properties'].keys())
 
     def __init__(
         self,
         name: str,
         authorization_url: str,
         scope: str,
-        client_id: str,
-        client_secret: str,
+        config: OAuth2ConnectorConfig,
         secrets_keeper: SecretsKeeper,
-        redirect_uri: str,
         token_url: str,
     ):
         self.auth_flow_id = name
         self.authorization_url = authorization_url
         self.scope = scope
-        self.client_id = client_id
-        self.client_secret = client_secret
-        self.redirect_uri = redirect_uri
+        self.config = config
         self.secrets_keeper = secrets_keeper
         self.token_url = token_url
 
     def build_authorization_url(self, **kwargs) -> str:
         """Build an authorization request that will be sent to the client."""
         client = OAuth2Session(
-            client_id=self.client_id,
-            client_secret=self.client_secret,
-            redirect_uri=self.redirect_uri,
+            client_id=self.config.client_id,
+            client_secret=self.config.client_secret.get_secret_value(),
+            redirect_uri=self.config.redirect_uri,
             scope=self.scope,
         )
         state = {'token': generate_token(), **kwargs}
@@ -65,9 +68,9 @@ class OAuth2Connector:
         url = url_parse.urlparse(authorization_response)
         url_params = url_parse.parse_qs(url.query)
         client = OAuth2Session(
-            client_id=self.client_id,
-            client_secret=self.client_secret,
-            redirect_uri=self.redirect_uri,
+            client_id=self.config.client_id,
+            client_secret=self.config.client_secret.get_secret_value(),
+            redirect_uri=self.config.redirect_uri,
         )
         saved_flow = self.secrets_keeper.load(self.auth_flow_id)
         if saved_flow is None:
@@ -90,8 +93,8 @@ class OAuth2Connector:
             if 'refresh_token' not in token:
                 raise NoOAuth2RefreshToken
             client = OAuth2Session(
-                client_id=self.client_id,
-                client_secret=self.client_secret,
+                client_id=self.config.client_id,
+                client_secret=self.config.client_secret.get_secret_value(),
             )
             new_token = client.refresh_token(self.token_url, refresh_token=token['refresh_token'])
             self.secrets_keeper.save(self.auth_flow_id, new_token)
